==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/pages/src/lib/printer-commands.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, WebCall, ServerAction, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-printer-commands",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-printer-commands"></i> <?php _('Printer Commands') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1" rsDrag>
          <div class="iconlist" style="padding: 0">
            <div class="button-icon sep-icon" *ngFor="let f of printer?.config?.quickCommands|quickCommands:printer.printing" style="flex-grow:1;flex-basis: auto;">
              <rs-button class="secondary outline full" (hit)="printerAction.sendGCode(printer.slug,f.command)">
                <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-play')"></rs-dyn-icon>
                <h3 class="text" style="padding:8px">{{f.name}}</h3></rs-button>
            </div>

            <div class="button-icon sep-icon" *ngFor="let f of webCallFiltered" style="flex-grow:1;flex-basis: auto;">
              <rs-button class="secondary outline full" (hit)="runWebCall(f)">
                <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-globe')"></rs-dyn-icon>
                <h3 class="text" style="padding:8px">{{f.show_name}}</h3></rs-button>
            </div>
          </div>
          <div *ngIf="printer?.config?.quickCommands?.length===0 && webCallFiltered.length===0" class="alert info margin">
            <?php _('No predefined commands defined!') ?>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class PrinterCommandsComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  webCalls$: Observable<WebCall[]>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];

  private printersSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public printerAction: PrinterAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.webCalls$ = store.select(s => s.server.webCalls);
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      const a: WebCall[] = [];
      w.forEach(x => {
        if (x.show_in_menu && x.slug === this.printer.slug) {
          a.push(x);
        }
      });
      this.webCallFiltered = a;
    });
  }

  runWebCall(cmd: WebCall) {
    if (cmd.question) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.question, {}).then(
        (res) => this.serverAction.runWebCall(cmd), () => {
        }
      );
    } else {
      this.serverAction.runWebCall(cmd);
    }
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
  }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/pages/src/lib/printer-commands.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, WebCall, ServerAction, RepetierState, ServerState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-printer-commands",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-printer-commands"></i> <?php _('Printer Commands') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1" rsDrag>
          <div *ngIf="(server$|async).features['show-quick-commands']">
            <div class="margin-leftright">
              <div class="iconlist" style="padding: 0">
                <div class="button-icon sep-icon" *ngFor="let f of printer?.config?.quickCommands|quickCommands:printer.printing" style="flex-grow:1;flex-basis: auto;">
                  <rs-button class="secondary outline full" (hit)="printerAction.sendGCode(printer.slug,f.command)">
                    <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-play')"></rs-dyn-icon>
                    <h3 class="text" style="padding:8px">{{ f.name }}</h3></rs-button>
                </div>

                <div class="button-icon sep-icon" *ngFor="let f of webCallFiltered" style="flex-grow:1;flex-basis: auto;">
                  <rs-button class="secondary outline full" (hit)="runWebCall(f)">
                    <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-globe')"></rs-dyn-icon>
                    <h3 class="text" style="padding:8px">{{ f.show_name }}</h3></rs-button>
                </div>
              </div>
              <div *ngIf="printer?.config?.quickCommands?.length===0 && webCallFiltered.length===0" class="alert info margin">
                <?php _('No predefined commands defined!') ?>
              </div>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class PrinterCommandsComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  webCalls$: Observable<WebCall[]>;
  server$: Observable<ServerState>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];

  private printersSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public printerAction: PrinterAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.webCalls$ = store.select(s => s.server.webCalls);
    this.server$ = store.select("server");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      const a: WebCall[] = [];
      w.forEach(x => {
        if (x.show_in_menu && x.slug === this.printer.slug) {
          a.push(x);
        }
      });
      this.webCallFiltered = a;
    });
  }

  runWebCall(cmd: WebCall) {
    if (cmd.question) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.question, {}).then(
        (res) => this.serverAction.runWebCall(cmd), () => {
        }
      );
    } else {
      this.serverAction.runWebCall(cmd);
    }
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
  }
}
